

log using $path/optimal, text replace
log on

use $data/base_estimation_wage_avtaxrate, clear
keep if tag2==. & samename==0
replace playquality4=3 if playquality4==4
save $data/base_table, replace



use $data/base_table, clear
g domestic=1-foreigner
xi: asclogit d mtr2 domestic ///
if year<2009, alternatives(countrymtr) case(id2) casev(age age2 top i.playquality4) cl(ident)
matrix results=e(b)
predict proba, pr
bys playquality4 : egen wage2=mean(wage) if year==2008

foreach country in Austria Belgium Denmark England France Germany Greece ///
 Italy Portugal Netherlands Norway Sweden Switzerland Spain{

g pw`country'=wage2*proba if  countrymtr=="`country'"
g dwage`country'=wage2 if  countrymtr=="`country'"
forval x=0(1)3{
local p=`x'+1
quietly su proba [w=proba] if countrymtr=="`country'" & year==2008 & playquality4==`x' 
scalar probaq`x'`country'=r(mean)
scalar alphaq`x'`country'=results[1,1]
scalar elastq`x'`country'=alphaq`x'`country'*(1-probaq`x'`country')

quietly su dwage`country' if countrymtr=="`country'" & year==2008 & playquality4==`x'
scalar sumpwq`x'`country'=r(sum)
scalar eq`x'`country'=sumpwq`x'`country'*elastq`x'`country'

}
scalar elasticity`country'=(eq0`country'+eq1`country'+eq2`country'+eq3`country')/(sumpwq0`country'+sumpwq1`country'+sumpwq2`country'+sumpwq3`country')

scalar tau`country'=1/(1+elasticity`country')
display "Optimal tax in `country' =" tau`country'
display "elasticity in `country' =" elasticity`country'
drop pw`country' dwage`country'
}

foreach country in Austria Belgium Denmark England France Germany Greece ///
 Italy Portugal Netherlands Norway Sweden Switzerland Spain{

g pw`country'=wage2*proba if  countrymtr=="`country'"
g dwage`country'=wage2 if  countrymtr=="`country'"
forval x=0(1)3{
local p=`x'+1
quietly su proba [w=proba] if countrymtr=="`country'" & year==2008 & playquality4==`x' & domestic==0
scalar probaq`x'`country'=r(mean)
scalar alphaq`x'`country'=results[1,1]
scalar elastq`x'`country'=alphaq`x'`country'*(1-probaq`x'`country')

quietly su dwage`country' if countrymtr=="`country'" & year==2008 & playquality4==`x' & domestic==0
scalar sumpwq`x'`country'=r(sum)
scalar eq`x'`country'=sumpwq`x'`country'*elastq`x'`country'

}
local elasticity`country'=(eq0`country'+eq1`country'+eq2`country'+eq3`country')/(sumpwq0`country'+sumpwq1`country'+sumpwq2`country'+sumpwq3`country')

drop pw`country' dwage`country'
}



clear
input  str5 country byte elast byte tau byte tau2  byte tau2f
"." . . . .  
end 
save  $data/laffer.dta, replace

foreach country in Austria Belgium Denmark England France Germany Greece ///
Italy Portugal Netherlands Norway Sweden Switzerland Spain{
local f=`f'+1
set obs 14
replace country="`country'" if _n==`f'
replace elast=elasticity`country' if _n==`f'
replace tau=tau`country' if _n==`f'
}

save  $data/laffer.dta, replace
 



/*  Optimal tau, model with rigid labor demand   */

use $data/base_table, clear
collapse wage if year==2008, by(playquality4)
save $data/ww, replace

use $data/base_multinomial_lowerleagues, clear
so playquality4
cap drop _merge
merge playquality4 using $data/ww
drop _merge

g mtr2q0=mtr2 if playquality4==0
replace mtr2q0=0 if playquality4!=0

g mtr2q1=mtr2 if playquality4>=1
replace mtr2q1=0 if playquality4<1

g q1=0
replace q1=1 if playquality4>0

keep if lower_league==.

xi: asclogit d mtr2q0 mtr2q1 domestic mtr_nf2_dom mtr_nd2_for ///
if year<2009, alternatives(countrymtr) case(id2) casev( age age2 top i.playquality4) cl(ident) iterate(25) collinear difficult ltolerance(1e-4) tolerance(1e-3)
matrix results=e(b)
predict proba, pr


/* OPtimal tau on foreigner */

foreach country in Austria Belgium Denmark England France Germany Greece ///
 Italy Portugal Netherlands Norway Sweden Switzerland Spain{

g pw`country'=wage*proba if  countrymtr=="`country'"
g dwage`country'=wage*d if  countrymtr=="`country'"


su mtr if countrymtr=="`country'" & year==2008  & domestic==1
scalar tau`country'dom=r(mean)
scalar alphadom`country'=_b[mtr_nf2_dom]

quietly su proba [w=proba] if countrymtr=="`country'" & year==2008  & domestic==1
scalar probadom`country'=r(mean)
scalar elastdom`country'=alphadom`country'*(1-probadom`country')

quietly su dwage`country' if countrymtr=="`country'" & year==2008 & domestic==1
scalar zdom`country'=r(sum)
quietly su dwage`country' if countrymtr=="`country'" & year==2008 & foreigner==1
scalar zfor`country'=r(sum)
scalar zdomzfor=min(6, zdom`country'/zfor`country')

scalar tau2f`country'=1/(1+`elasticity`country'')*(1-tau`country'dom*elastdom`country'*zdomzfor)

display "Optimal tax on foreigner in `country' =" tau2f`country' 
display "elasticity foreigner in `country' =" `elasticity`country''
display "elasticity dom w.r.t tax foreigner in `country' =" elastdom`country'
display "ratio earnings dom / foreigner in `country' =" zdomzfor
display "earnings dom / foreigner in `country' =" zdom`country' "/" zfor`country'
}

drop pwAustria- dwageSpain




/* Optimal tau domestic & foreigners (one unique tax rate) */

foreach country in Austria Belgium Denmark England France Germany Greece ///
 Italy Portugal Netherlands Norway Sweden Switzerland Spain{

g pw`country'=wage*proba if  countrymtr=="`country'"
g dwage`country'=wage*d if  countrymtr=="`country'"


forval x=0(1)1{
local p=`x'
quietly su proba [w=proba] if countrymtr=="`country'" & year==2008 & q1==`x' & foreigner==1
scalar probaq`x'`country'=cond(r(mean)!=., r(mean), 0)
scalar alphaq`x'`country'=_b[mtr2q`p']
scalar betaq`x'`country'=_b[mtr_nd2_for]
scalar elastq`x'`country'=(alphaq`x'`country'+betaq`x'`country')*(1-probaq`x'`country')
quietly su pw`country' if countrymtr=="`country'" & year==2008 & q1==`x' & foreigner==1
scalar sumforpwq`x'`country'=cond(r(mean)!=., r(mean), 0)
scalar eqfor`x'`country'=sumforpwq`x'`country'*elastq`x'`country'
}

forval x=0(1)1{
local p=`x'
quietly su proba [w=proba] if countrymtr=="`country'" & year==2008 & q1==`x' & foreigner==0
scalar probaq`x'`country'=cond(r(mean)!=., r(mean), 0)
scalar alphaq`x'`country'=_b[mtr2q`p']
scalar betaq`x'`country'=_b[mtr_nf2_dom]
scalar elastq`x'`country'=(alphaq`x'`country'+betaq`x'`country')*(1-probaq`x'`country')
quietly su pw`country' if countrymtr=="`country'" & year==2008 & q1==`x' & foreigner==0
scalar sumdompwq`x'`country'=cond(r(mean)!=., r(mean), 0)
scalar eqdom`x'`country'=sumdompwq`x'`country'*elastq`x'`country'
}

scalar elasticity`country'=(eqfor0`country'+eqfor1`country' + eqdom0`country'+eqdom1`country') / ///
(sumforpwq0`country'+sumforpwq1`country'+sumdompwq0`country'+sumdompwq1`country')


scalar tau2`country'=1/(1+elasticity`country')

display "Optimal tax everybody in `country' =" tau2`country' 
display "elasticity everybody with displacement & sorting effects in `country' =" elasticity`country'
}
drop pwAustria- dwageSpain


use $data/laffer.dta, clear
foreach country in Austria Belgium Denmark England France Germany Greece ///
Italy Portugal Netherlands Norway Sweden Switzerland Spain{
local i=`i'+1
set obs 14
replace tau2=tau2`country' if _n==`i'
replace tau2f=tau2f`country' if _n==`i'
}
so country
save  $data/laffer.dta, replace 


/*Export table of Laffer rates in .txt format, ready to use in a .tex file */

use $data/mtr, clear
keep if year==2008
drop if country=="Ireland"
replace country="England" if country=="United Kingdom"
keep country mtrforeigner mtrlocal
so country
merge country using $data/laffer

set obs 15

drop _merge
keep country mtrlocal mtrforeigner tau tau2 tau2f
order country mtrlocal mtrforeigner tau tau2 tau2f
foreach var in mtrlocal mtrforeigner tau tau2 tau2f{
replace `var'=round(`var'*1000)/1000
quietly su `var'
replace `var'=round(`r(mean)'*1000)/1000 if _n==15
} 
g lastcol="\\"
outsheet using "$path/laffer.txt", delimiter("&") noquote replace


erase $data/base_table.dta
erase $data/laffer.dta
erase $data/ww.dta

log off
log close



