


log using "$path/table3.txt", replace text
log on

/* Dataset to store all the elasticities */
clear
input byte foreigner str5 elast1 str15 elast2 str15 elast3 str15 elast4
. "." "." "." "." 
end 
save  $path/elasticities_table3, replace

cap program drop elasticities
program define elasticities
args  model
preserve
quietly{
estat mfx, varlist(mtr2) at(mean Spain: foreigner=0)
matrix define b=r(Spain)
local epsilon_l=b[12,1]/r(pr_Spain)
local se_epsilon_l=b[12,2]/r(pr_Spain)
estat mfx, varlist(mtr2) at(mean Spain: foreigner=1)
matrix define b=r(Spain)
local epsilon_f=b[12,1]/r(pr_Spain)
local se_epsilon_f=b[12,2]/r(pr_Spain)
}
display "epsilon= " `epsilon_l' "  se = " `se_epsilon_l'
display "epsilon_f= " `epsilon_f' "  se = " `se_epsilon_f'

use $path/elasticities_table3, clear
set obs 4
replace foreigner=0 if _n<3
replace elast`model'="`epsilon_l'" if _n==1
replace elast`model'="`se_epsilon_l'" if _n==2
replace foreigner=1 if _n>=3
replace elast`model'="`epsilon_f'" if _n==3
replace elast`model'="`se_epsilon_f'" if _n==4
save $path/elasticities_table3, replace
end


/* Model 1: no country fixed effects */
use $data/base_multinomial_lowerleagues, clear
xi: asclogit d mtr2 foreigner ///
if year<2009, alternatives(countrymtr) case(id2) cl(ident) noconstant iterate(25)  collinear difficult ltolerance(1e-4) tolerance(1e-3)
est store multin1
estat ic
local ell=e(ll)
elasticities 1


/* Model 2:  country fixed effects */
use $data/base_multinomial_lowerleagues, clear
cap drop __tvar_*
xi: asclogit d mtr2 foreigner ///
if year<2009, alternatives(countrymtr) case(id2) casev(/*age age2*/ top i.playquality4) cl(ident) iterate(25)  collinear difficult ltolerance(1e-4) tolerance(1e-3)
est store multin2
estat ic
local ell=e(ll)
elasticities 2

/* Model 3:  country fixed effects interacted with year fixed effects */
use $data/base_multinomial_lowerleagues, clear
cap drop __tvar_*
xi: asclogit d mtr2 foreigner ///
if year<2009, alternatives(countrymtr) case(id2) casev(/*age age2*/ top i.playquality4 i.year) cl(ident) iterate(25) collinear difficult ltolerance(1e-4) tolerance(1e-3)
est store multin3
estat ic
local ell=e(ll)
elasticities 3


********** Excluding lower leagues for the same time period (1999 and after)
/* Model 1: no country fixed effects */
use $data/base_estimation_wage_avtaxrate, clear
keep if tag2==. & samename==0
replace playquality4=3 if playquality4==4
keep if year>=1999

cap drop __tvar_*
xi: asclogit d mtr2 foreigner ///
if year<2009 /*& lower_league==.*/, alternatives(countrymtr) case(id2) cl(ident) noconstant iterate(25) collinear difficult ltolerance(1e-4) tolerance(1e-3)
est store multin1bis



/* Model 2:  country fixed effects */
cap drop __tvar_*
xi: asclogit d mtr2 foreigner ///
if year<2009  /*& lower_league==.*/, alternatives(countrymtr) case(id2) casev(/*age age2*/ top i.playquality4) cl(ident) iterate(25) collinear difficult ltolerance(1e-4) tolerance(1e-3)
est store multin2bis


/* Model 3:  country fixed effects interacted with year fixed effects */
cap drop __tvar_*
xi: asclogit d mtr2 foreigner ///
if year<2009  /*& lower_league==.*/, alternatives(countrymtr) case(id2) casev(/*age age2*/ top i.playquality4 i.year) cl(ident) iterate(25) collinear difficult ltolerance(1e-4) tolerance(1e-3)
est store multin3bis




*******************************************************************************************************
* Model with sorting effects
*********************************************************************************************************
use $data/base_multinomial_lowerleagues, clear

g mtr2q0=mtr2 if playquality4==0
replace mtr2q0=0 if playquality4!=0

g mtr2q1=mtr2 if playquality4>=1
replace mtr2q1=0 if playquality4<1

g q1=0
replace q1=1 if playquality4>=1

cap drop __tvar_*
xi: asclogit d mtr2q0 mtr2q1 domestic ///
if year<2009, alternatives(countrymtr) case(id2) casev( q1) cl(ident) iterate(25) collinear difficult ltolerance(1e-4) tolerance(1e-3)
est store crosseff1

cap drop __tvar_*
xi: asclogit d mtr2q0 mtr2q1 domestic mtr_nf2_dom mtr_nd2_for ///
if year<2009, alternatives(countrymtr) case(id2) casev( q1) cl(ident) iterate(25) collinear difficult ltolerance(1e-4) tolerance(1e-3)
est store crosseff2


keep if lower_league==.

xi: asclogit d mtr2q0 mtr2q1 domestic ///
if year<2009, alternatives(countrymtr) case(id2) casev( age age2 top i.playquality4) cl(ident) iterate(25) collinear difficult ltolerance(1e-4) tolerance(1e-3)
est store crosseff1bis

cap drop __tvar_*
xi: asclogit d mtr2q0 mtr2q1 domestic mtr_nf2_dom mtr_nd2_for ///
if year<2009, alternatives(countrymtr) case(id2) casev( age age2 top i.playquality4) cl(ident) iterate(25) collinear difficult ltolerance(1e-4) tolerance(1e-3)
est store crosseff2bis


esttab multin1 multin2 multin3  crosseff1 crosseff2 using "$path/lowerleague_cl1.tex", ///
replace keep(mtr2 foreigner mtr2q0 mtr2q1 mtr_nf2_dom mtr_nd2_for) se scalars(N r2)

esttab multin1bis multin2bis multin3bis crosseff1bis crosseff2bis using "$path/lowerleague_cl1bis.tex", ///
replace keep(mtr2 foreigner mtr2q0 mtr2q1 mtr_nf2_dom mtr_nd2_for) se scalars(N r2)

esttab multin1 multin2 multin3 multin1bis multin2bis multin3bis crosseff1 crosseff1bis crosseff2 crosseff2bis using "$path/lowerleague_cl1total.tex", ///
replace keep(mtr2 foreigner mtr2q0 mtr2q1 mtr_nf2_dom mtr_nd2_for) se scalars(N r2)




log off
log close

