
/* 

weights to compute synthetic denmark: taken from minimization of distance 
for same vector of characteristics as in other synthetic control + number of foreigners between 1985 and 1990 

*/

use $pathdata/basesynthetic_control.dta, clear
local min_y= 1985
keep if year>=`min_y'
synth f f quality playquality2 country_coef_1  country_sumtotpts_rel uefa_coef_1, trunit(4) trperiod(1991) 
matrix w7=e(W_weights)



use $pathdata/basedenmarkduration, clear
keep if nationality!=country
keep if second=="-"
drop if nationality=="-"

g year_arriv=year(date_arr) 
g year_dep=year(date_dep)

local last_yrarrival=2002

keep if year_arriv>=1992 & year_arriv<=`last_yrarrival'



* Regression to compute excess bunching at 3 years *
g threeyears=duration==3
*weights: taken from minimization of distance for same vector of characteristics as in other synthetic control + number of foreigners between 1985 and 1990 
g weights=0
replace weights=1 if country=="Denmark"
replace weights=.05 if country=="Spain"
replace weights=.67 if country=="Greece"
replace weights=.263  if country=="Norway"
replace weights=.01 if country=="Sweden"

g Den=country=="Denmark"

logit threeyears Den [pw=weights]
local b=round(_b[Den]*100)/100
local se=round(_se[Den]*100)/100

collapse duration, by(long_name last_name date_arr country)
replace duration=round(duration)
replace duration=1 if duration==0

g compteur=1
collapse (sum) compteur, by(country duration)
bys country: egen totcountry=sum(compteur)
g frac=compteur/totcountry

replace frac=0 if frac==.

save $pathdata/base_tempduration, replace
keep if country=="Denmark"
rename frac yDenmark
so duration
save $pathdata/base_graph_synthetic_duration, replace

foreach country in  Austria Belgium Denmark England France Germany Greece Italy Portugal Netherlands Norway Sweden Switzerland Spain{
use $pathdata/base_tempduration, clear
keep if country=="`country'"
rename frac y`country'
so duration
merge duration using $pathdata/base_graph_synthetic_duration
drop _merge
so duration
save $pathdata/base_graph_synthetic_duration, replace
}

foreach country in  Austria Belgium Denmark England France Germany Greece Italy Portugal Netherlands Norway Sweden Switzerland Spain{
use $pathdata/base_graph_synthetic_duration, clear
replace y`country'=0 if y`country'==.
save $pathdata/base_graph_synthetic_duration, replace
}

*weights: taken from minimization of distance for same vector of characteristics as in other synthetic control + number of foreigners between 1985 and 1990 
g synthetic_y=.
replace synthetic_y=.05*ySpain+.67*yGr+.263*yNor+.01*ySwede


twoway (line yDenmark duration if duration<=10 & duration>0, xline(3.5) lcolor(black) mcolor(black) msize(small)) ///
(line synthetic_y duration if duration<=10 & duration>0, lcolor(black) mcolor(black) lpattern(dash) msize(small)), ///
ytitle("Fraction of foreign players")  xlabel(0(2)10, grid glc(gs14))  ///
xtitle(Duration of stay in years)  legend(cols(2) label(1 "Denmark")  label(2 "Synthetic Denmark")) graphregion(fcolor(white)) ///
ttext(.35 7 "d Pr(Duration=3) / d(Denm=1) = `b' (`se')"  "Duration elasticity {&asymp} .3", box just(center) fcolor(white) margin(medsmall) size(medsmall))

graph export "$pathgraph/Denmarksynthduration_`last_yrarrival'.eps", replace

erase $pathdata/base_graph_synthetic_duration.dta
erase $pathdata/base_tempduration.dta
