*********************************************************************************************************************************
*********************************************************************************************************************************
*****
*****
*****        This program creates graphs showing that labor demand is not totally rigid, but in fact downward slopping					
*********************************************************************************************************************************
*********************************************************************************************************************************

use $pathdata/baseplayer.dta, clear


g foreigner=country!=nationality

g mtrplayer=mtrlocal
replace mtrplayer=mtrf if foreigner==1
cap drop reform
cap drop compteur

g compteur=1
g reform=year>1995
keep if reform==1
collapse (sum) compteur (mean) mtrf mtrl mtrplayer reform if year<2009, by(country year club)
collapse compteur mtrf mtrl mtrplayer  if year<2009, by(country )

g natlabel=substr(country, 1, 2)
replace natlabel="SE" if country=="Sweden"
replace natlabel="AT" if country=="Austria"
replace natlabel="BE" if country=="Belgium"
replace natlabel="DK" if country=="Denmark"
replace natlabel="UK" if country=="England"
replace natlabel="FR" if country=="France"
replace natlabel="DE" if country=="Germany"
replace natlabel="GR" if country=="Greece"
replace natlabel="IT" if country=="Italy"
replace natlabel="NL" if country=="Netherlands"
replace natlabel="NO" if country=="Norway"
replace natlabel="PT" if country=="Portugal"
replace natlabel="ES" if country=="Spain"
replace natlabel="CH" if country=="Switzerland"
* We plot the average number of player by club for each country and average tax rate on locals for years 1995-2009
* regression fit estimates	
reg compteur mtrplayer 
local beta=round(_b[mtrplayer]*100)/100
local se=round(_se[mtrplayer]*100)/100

twoway (scatter compteur mtrplayer, mlabel(natlabel)) ///
(lfit compteur mtrplayer, lc(red)), ///
ytitle("Average number of players by team")  ylabel(15 (5) 40) legend(off) xtitle("Top earnings tax rate")  graphregion(fcolor(white)) ///
ttext(35 .7 "Slope= `beta' (`se')", box just(left) fcolor(white) margin(medsmall)) 


graph export "$pathgraph/Labordemand1.eps", replace





use $pathdata/baseplayer.dta, clear

g foreigner=country!=nationality
g mtrplayer=mtrlocal
replace mtrplayer=mtrf if foreigner==1

cap drop compteur
cap drop reform
g compteur=1
g reform=year>1995
keep if reform==0 & year>1989
collapse (sum) compteur (mean) mtrf mtrl mtrplayer reform if year<2009, by(country year club)
collapse compteur mtrf mtrl mtrplayer  if year<2009, by(country )
g natlabel=substr(country, 1, 2)
replace natlabel="SE" if country=="Sweden"
replace natlabel="AT" if country=="Austria"
replace natlabel="BE" if country=="Belgium"
replace natlabel="DK" if country=="Denmark"
replace natlabel="UK" if country=="England"
replace natlabel="FR" if country=="France"
replace natlabel="DE" if country=="Germany"
replace natlabel="GR" if country=="Greece"
replace natlabel="IT" if country=="Italy"
replace natlabel="NL" if country=="Netherlands"
replace natlabel="NO" if country=="Norway"
replace natlabel="PT" if country=="Portugal"
replace natlabel="ES" if country=="Spain"
replace natlabel="CH" if country=="Switzerland"
* We plot the average number of player by club for each country and average tax rate on locals for years 1995-2009
reg compteur mtrplayer 
local beta=round(_b[mtrplayer]*100)/100
local se=round(_se[mtrplayer]*100)/100

twoway (scatter compteur mtrplayer, mlabel(natlabel)) ///
(lfit compteur mtrplayer, lc(red)), ///
ytitle("Average number of players by team")  ylabel(15 (5) 40) legend(off) xtitle("Top earnings tax rate")  graphregion(fcolor(white)) ///
ttext(35 .7 "Slope= `beta' (`se')", box just(left) fcolor(white) margin(medsmall)) 

graph export "$pathgraph/Labordemand1_befBosm.eps", replace

* regression fit estimates	
reg compteur mtrplayer 







*** Number of teams:

use $pathdata/baseplayer.dta, clear
so country year

g foreigner=country!=nationality

g mtrplayer=mtrlocal
replace mtrplayer=mtrf if foreigner==1

g compteur=1
g reform=year>1995
collapse (mean) compteur (mean) mtrf mtrl mtrplayer reform if year<2009, by(country year club)
collapse (sum) compteur (mean) mtrf mtrl mtrplayer reform if year<2009, by(country year)
collapse (mean) compteur mtrf mtrl mtrplayer  if year<2009 & year>1995, by(country )
g natlabel=substr(country, 1, 2)
replace natlabel="SE" if country=="Sweden"
replace natlabel="AT" if country=="Austria"
replace natlabel="BE" if country=="Belgium"
replace natlabel="DK" if country=="Denmark"
replace natlabel="UK" if country=="England"
replace natlabel="FR" if country=="France"
replace natlabel="DE" if country=="Germany"
replace natlabel="GR" if country=="Greece"
replace natlabel="IT" if country=="Italy"
replace natlabel="NL" if country=="Netherlands"
replace natlabel="NO" if country=="Norway"
replace natlabel="PT" if country=="Portugal"
replace natlabel="ES" if country=="Spain"
replace natlabel="CH" if country=="Switzerland"
/* Bug in the way some club names are recorded for Germany ; +> the budesliga counts 18 clubs since 1992 */
replace compteur=18 if country=="Germany"

* We plot the average number of teams by country and average tax rate on locals for years 1995-2009

* regression fit estimates	
reg compteur mtrplayer 
local beta=round(_b[mtrplayer]*100)/100
local se=round(_se[mtrplayer]*100)/100

twoway (scatter compteur mtrplayer, mlabel(natlabel)) ///
(lfit compteur mtrplayer, lc(red)), ///
ytitle("Average number of teams by country")  ylabel(10 (2) 20) legend(off) xtitle("Top earnings tax rate")  graphregion(fcolor(white)) ///
ttext(18 .7 "Slope= `beta' (`se')", box just(left) fcolor(white) margin(medsmall)) 

graph export "$pathgraph/Labordemand2.eps", replace






use $pathdata/baseplayer.dta, clear
so country year

g foreigner=country!=nationality

g mtrplayer=mtrlocal
replace mtrplayer=mtrf if foreigner==1


g compteur=1
g reform=year>1995
keep if reform==0 & year>1989
collapse (mean) compteur (mean) mtrf mtrl mtrplayer reform if year<2009, by(country year club)
collapse (sum) compteur (mean) mtrf mtrl mtrplayer reform if year<2009, by(country year)
collapse (mean) compteur mtrf mtrl mtrplayer  if year<2009, by(country )
g natlabel=substr(country, 1, 2)
replace natlabel="SE" if country=="Sweden"
replace natlabel="AT" if country=="Austria"
replace natlabel="BE" if country=="Belgium"
replace natlabel="DK" if country=="Denmark"
replace natlabel="UK" if country=="England"
replace natlabel="FR" if country=="France"
replace natlabel="DE" if country=="Germany"
replace natlabel="GR" if country=="Greece"
replace natlabel="IT" if country=="Italy"
replace natlabel="NL" if country=="Netherlands"
replace natlabel="NO" if country=="Norway"
replace natlabel="PT" if country=="Portugal"
replace natlabel="ES" if country=="Spain"
replace natlabel="CH" if country=="Switzerland"
/* Bug in the way some club names are recorded for Germany ; +> the budesliga counts 18 clubs since 1992 */
replace compteur=18 if country=="Germany"

* regression fit estimates	
reg compteur mtrplayer 
local beta=round(_b[mtrplayer]*100)/100
local se=round(_se[mtrplayer]*100)/100
* We plot the average number of teams by country and average tax rate on locals for years 1995-2009

twoway (scatter compteur mtrplayer, mlabel(natlabel)) ///
(lfit compteur mtrplayer, lc(red)), ///
ytitle("Average number of teams by country")  ylabel(10 (2) 20) legend(off) xtitle("Top earnings tax rate")  graphregion(fcolor(white)) ///
ttext(18 .7 "Slope= `beta' (`se')", box just(left) fcolor(white) margin(medsmall)) 

graph export "$pathgraph/Labordemand2_befBosm.eps", replace





